package com.yiqi.order.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.order.domain.dto.OrderPurchaseGoodsQueryDTO;
import com.yiqi.order.domain.vo.OrderPurchaseGoodsVO;
import com.yiqi.order.domain.vo.OrderSellGoodsListVO;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.order.domain.OrderPurchaseGoods;

/**
 * 商品订单Mapper接口
 *
 * @author ruoyi
 * @date 2023-10-17
 */
@Mapper
public interface OrderPurchaseGoodsMapper extends BaseMapper<OrderPurchaseGoods> {
    /**
     * 查询商品订单
     *
     * @param id 商品订单主键
     * @return 商品订单
     */
    public List<OrderPurchaseGoodsVO> selectOrderPurchaseGoodsById(Long id);

    /**
     * 查询商品订单列表
     *
     * @param orderPurchaseGoods 商品订单
     * @return 商品订单集合
     */
    public List<OrderPurchaseGoods> selectOrderPurchaseGoodsList(OrderPurchaseGoods orderPurchaseGoods);

    /**
     * 查询商品订单列表
     *
     * @param orderPurchaseGoodsQueryDTO 商品订单
     * @return 商品订单集合
     */
    public List<OrderSellGoodsListVO> sellGoodsListByFactory(OrderPurchaseGoodsQueryDTO orderPurchaseGoodsQueryDTO);

    /**
     * 查询商品订单列表
     *
     * @param orderPurchaseGoodsQueryDTO 商品订单
     * @return 商品订单集合
     */
    public List<OrderSellGoodsListVO> sellGoodsListByHq(OrderPurchaseGoodsQueryDTO orderPurchaseGoodsQueryDTO);

    /**
     * 新增商品订单
     *
     * @param orderPurchaseGoods 商品订单
     * @return 结果
     */
    public int insertOrderPurchaseGoods(OrderPurchaseGoods orderPurchaseGoods);

    /**
     * 修改商品订单
     *
     * @param orderPurchaseGoods 商品订单
     * @return 结果
     */
    public int updateOrderPurchaseGoods(OrderPurchaseGoods orderPurchaseGoods);

    /**
     * 删除商品订单
     *
     * @param id 商品订单主键
     * @return 结果
     */
    public int deleteOrderPurchaseGoodsById(Long id);

    /**
     * 批量删除商品订单
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderPurchaseGoodsByIds(Long[] ids);
}
